summaryrefslogtreecommitdiff
path: root/scripts/wsrep_sst_mariabackup.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/wsrep_sst_mariabackup.sh')
-rw-r--r--scripts/wsrep_sst_mariabackup.sh35
1 files changed, 19 insertions, 16 deletions
diff --git a/scripts/wsrep_sst_mariabackup.sh b/scripts/wsrep_sst_mariabackup.sh
index a6934f3881f..45205204c93 100644
--- a/scripts/wsrep_sst_mariabackup.sh
+++ b/scripts/wsrep_sst_mariabackup.sh
@@ -95,9 +95,9 @@ sst_ver=1
declare -a RC
-BACKUP_BIN=$(commandex 'mariabackup')
+BACKUP_BIN=$(commandex 'mariadb-backup')
if [ -z "$BACKUP_BIN" ]; then
- wsrep_log_error 'mariabackup binary not found in path'
+ wsrep_log_error 'mariadb-backup binary not found in path'
exit 42
fi
@@ -340,6 +340,9 @@ get_transfer()
"Use workaround for socat $SOCAT_VERSION bug"
fi
fi
+ if check_for_version "$SOCAT_VERSION" '1.7.4'; then
+ tcmd="$tcmd,no-sni=1"
+ fi
fi
if [ "${sockopt#*,dhparam=}" = "$sockopt" ]; then
@@ -685,7 +688,7 @@ cleanup_at_exit()
if [ -n "$BACKUP_PID" ]; then
if check_pid "$BACKUP_PID" 1; then
wsrep_log_error \
- "mariabackup process is still running. Killing..."
+ "mariadb-backup process is still running. Killing..."
cleanup_pid $CHECK_PID "$BACKUP_PID"
fi
fi
@@ -761,7 +764,7 @@ check_extra()
if [ "$thread_handling" = 'pool-of-threads' ]; then
local eport=$(parse_cnf '--mysqld' 'extra-port')
if [ -n "$eport" ]; then
# mariabackup works only locally.
# Hence, setting host to 127.0.0.1 unconditionally:
wsrep_log_info "SST through extra_port $eport"
INNOEXTRA="$INNOEXTRA --host=127.0.0.1 --port=$eport"
@@ -930,7 +933,7 @@ cd "$OLD_PWD"
if [ $ssyslog -eq 1 ]; then
if [ -n "$(commandex logger)" ]; then
- wsrep_log_info "Logging all stderr of SST/mariabackup to syslog"
+ wsrep_log_info "Logging all stderr of SST/mariadb-backup to syslog"
exec 2> >(logger -p daemon.err -t ${ssystag}wsrep-sst-$WSREP_SST_OPT_ROLE)
@@ -1053,11 +1056,11 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
xtmpdir=$(TMPDIR="$tmpdir"; mktemp '-d')
fi
- wsrep_log_info "Using '$xtmpdir' as mariabackup temporary directory"
+ wsrep_log_info "Using '$xtmpdir' as mariadb-backup temporary directory"
tmpopts=" --tmpdir='$xtmpdir'"
itmpdir="$(mktemp -d)"
- wsrep_log_info "Using '$itmpdir' as mariabackup working directory"
+ wsrep_log_info "Using '$itmpdir' as mariadb-abackup working directory"
usrst=0
if [ -n "$WSREP_SST_OPT_USER" ]; then
@@ -1148,7 +1151,7 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
fi
# if compression is enabled for backup files, then add the
# appropriate options to the mariabackup command line:
if [ "$compress" != 'none' ]; then
iopts="--compress${compress:+=$compress}${iopts:+ }$iopts"
if [ -n "$compress_threads" ]; then
@@ -1170,7 +1173,7 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
set -e
if [ ${RC[0]} -ne 0 ]; then
- wsrep_log_error "mariabackup finished with error: ${RC[0]}." \
+ wsrep_log_error "mariadb-backup finished with error: ${RC[0]}." \
"Check syslog or '$INNOBACKUPLOG' for details"
exit 22
elif [ ${RC[$(( ${#RC[@]}-1 ))]} -eq 1 ]; then
@@ -1178,7 +1181,7 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
exit 22
fi
# mariabackup implicitly writes PID to fixed location in $xtmpdir
BACKUP_PID="$xtmpdir/xtrabackup_pid"
else # BYPASS FOR IST
@@ -1450,14 +1453,14 @@ else # joiner
if [ ! -s "$DATA/mariadb_backup_checkpoints" ]; then
wsrep_log_error "mariadb_backup_checkpoints missing," \
- "failed mariabackup/SST on donor"
+ "failed mariadb-backup/SST on donor"
exit 2
fi
# Compact backups are not supported by mariabackup
if grep -qw -F 'compact = 1' "$DATA/mariadb_backup_checkpoints"; then
wsrep_log_info "Index compaction detected"
- wsrel_log_error "Compact backups are not supported by mariabackup"
+ wsrel_log_error "Compact backups are not supported by mariadb-backup"
exit 2
fi
@@ -1509,9 +1512,9 @@ else # joiner
wsrep_log_info "Preparing the backup at $DATA"
setup_commands
- timeit 'mariabackup prepare stage' "$INNOAPPLY"
+ timeit 'mariadb-backup prepare stage' "$INNOAPPLY"
if [ $? -ne 0 ]; then
- wsrep_log_error "mariabackup apply finished with errors." \
+ wsrep_log_error "mariadb-backup apply finished with errors." \
"Check syslog or '$INNOAPPLYLOG' for details."
exit 22
fi
@@ -1556,7 +1559,7 @@ else # joiner
MAGIC_FILE="$TDATA/$INFO_FILE"
wsrep_log_info "Moving the backup to $TDATA"
- timeit 'mariabackup move stage' "$INNOMOVE"
+ timeit 'mariadb-backup move stage' "$INNOMOVE"
if [ $? -eq 0 ]; then
wsrep_log_info "Move successful, removing $DATA"
rm -rf "$DATA"
@@ -761,7 +764,7 @@ check_extra()
local eport=$(parse_cnf '--mysqld' 'extra-port')
if [ -n "$eport" ]; then
- # mariabackup works only locally.
+ # mariadb-backup works only locally.
# Hence, setting host to 127.0.0.1 unconditionally:
wsrep_log_info "SST through extra_port $eport"
@@ -1148,7 +1151,7 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
fi
# if compression is enabled for backup files, then add the
- # appropriate options to the mariabackup command line:
+ # appropriate options to the mariadb-backup command line:
if [ "$compress" != 'none' ]; then
iopts="--compress${compress:+=$compress}${iopts:+ }$iopts"
@@ -1178,7 +1181,7 @@ if [ "$WSREP_SST_OPT_ROLE" = 'donor' ]; then
exit 22
fi
- # mariabackup implicitly writes PID to fixed location in $xtmpdir
+ # mariadb-backup implicitly writes PID to fixed location in $xtmpdir
BACKUP_PID="$xtmpdir/xtrabackup_pid"
else # BYPASS FOR IST
@@ -1450,14 +1453,14 @@ else # joiner
exit 2
fi
- # Compact backups are not supported by mariabackup
+ # Compact backups are not supported by mariadb-backup
if grep -qw -F 'compact = 1' "$DATA/mariadb_backup_checkpoints"; then
wsrep_log_info "Index compaction detected"